@@ -1,10 +1,10 @@
-/* $Id: RTMpGetArraySize-generic.cpp 70492 2011-03-10 17:22:08Z bird $ */
+/* $Id: RTMpGetArraySize-generic.cpp 83687 2013-02-08 12:50:49Z fmehnert $ */
 /** @file
  * IPRT - Multiprocessor, Generic RTMpGetArraySize.
  */
 
 /*
- * Copyright (C) 2010-2011 Oracle Corporation
+ * Copyright (C) 2010-2012 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -51,7 +51,7 @@ RTDECL(uint32_t) RTMpGetArraySize(void)
         RTCPUSET    CpuSet;
         uint32_t    cCpus1 = RTCpuLastIndex(RTMpGetSet(&CpuSet)) + 1;
         uint32_t    cCpus2 = RTMpGetCount();
-        uint32_t    cCpus  = RT_MAX(cCpus1, cCpus2);
+        cCpus              = RT_MAX(cCpus1, cCpus2);
         ASMAtomicCmpXchgU32(&s_cMaxCpus, cCpus, 0);
         return cCpus;
     }
